from netbox.settings import VERSION # type: ignore
if VERSION.startswith("3."):
    from extras.plugins import get_plugin_config # type: ignore
else:
    from netbox.plugins import get_plugin_config # type: ignore
    
import re

    
class ContextMenusMiddleware:

    def __init__(self, get_response):
        self.get_response = get_response
    
    def __call__(self, request):
        response = self.get_response(request)
        request_path = request.get_full_path()
        NBCM_JSPATH = get_plugin_config('netbox_contextmenus', 'nbcmjspath')

        if request_path.startswith('/api/'):
            return response
        if NBCM_JSPATH == request.get_full_path():
            return response

        NBCM_JS = '<script src="'+NBCM_JSPATH+'" defer></script>'
        content = str(response.content)
        if not NBCM_JS in content:            
            response.content=re.sub(
                    b'</head>',
                    bytes(NBCM_JS, response.charset) + b'\n  </head>',
                    response.content,
                    flags=re.IGNORECASE
                )
        return response



from netbox.settings import VERSION # type: ignore
if VERSION.startswith("3."):
    from extras.plugins import PluginConfig # type: ignore
else:
    from netbox.plugins import PluginConfig # type: ignore

from .pluginvars import (
    __version__,
    __name__,
    __description__,
    __author__,
    __author_email__,
)


class NetboxContextMenusConfig(PluginConfig):
    name = __name__
    verbose_name = "NetBox ContextMenu"
    description = __description__
    version = __version__
    author = __author__
    author_email = __author_email__
    required_settings = []
    default_settings = {
        'nbcmjspath': '/plugins/netbox_contextmenus/nbcmrender/',
        'nbcmopendelay': 150
    }
    baseurl = "netbox_contextmenus"
    middleware = ["netbox_contextmenus.middleware.ContextMenusMiddleware"]

config = NetboxContextMenusConfig



__name__ = 'netbox_contextmenus'
__version__ = '1.4.5'
__description__ = 'Add context menu to links in NetBox'
__author__ = 'Pieter Lambrecht'
__author_email__ = 'pieter.lambrecht@gmail.com'
__url__ = 'https://github.com/PieterL75/netbox_contextmenus'



from django.shortcuts import render
from django.views.generic import View

from netbox.settings import VERSION # type: ignore
if VERSION.startswith("3."):
    from extras.plugins import get_plugin_config # type: ignore
else:
    from netbox.plugins import get_plugin_config # type: ignore

class ContextMenuRenderView(View):
    def get(self, request):
        return render(
            request, 
            'netbox_contextmenus/nbcm.js', 
            { 'opendelay' : get_plugin_config('netbox_contextmenus', 'nbcmopendelay') }, 
            content_type='application/javascript'
        )



import codecs
import os.path

from setuptools import find_packages, setup


with open("README.md", "r") as fh:
    long_description = fh.read()


def read(rel_path):
    here = os.path.abspath(os.path.dirname(__file__))
    with codecs.open(os.path.join(here, rel_path), 'r') as fp:
        return fp.read()


def get_pluginvar(variable,rel_path):
    for line in read(rel_path).splitlines():
        if line.startswith(f'__{variable}__'):
            delim = '"' if '"' in line else "'"
            return line.split(delim)[1]
    else:
        raise RuntimeError(f"Unable to find {variable} string in f{rel_path}.")


setup(
    name=get_pluginvar('name','netbox_contextmenus/pluginvars.py'),
    version=get_pluginvar('version','netbox_contextmenus/pluginvars.py'),
    description=get_pluginvar('description','netbox_contextmenus/pluginvars.py'),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=get_pluginvar('url','netbox_contextmenus/pluginvars.py'),
    author=get_pluginvar('author','netbox_contextmenus/pluginvars.py'),
    author_email=get_pluginvar('author_email','netbox_contextmenus/pluginvars.py'),
    install_requires=[],
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Framework :: Django',
        'Programming Language :: Python :: 3',
    ]
)